==> aroundme_0_3_3.tar: aroundme_0_3_3/www/aroundme_0_3_3/template/am_default/welcome.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="375" valign="top">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_welcome'] . " " . $user['user_firstname'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_introduction'];?><br />
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" width="100%" cellspacing="0" cellpadding="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_friends'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($friends[0])) {
				foreach($friends as $key => $i):
				?>
				<tr>
					<td>

						<table border="0" width="100%" cellspacing="0" cellpadding="4">
							<tr>
								<td valign="top" width="80">
									<a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><img src="get_image.php?img=<?php echo $i['image']['image'];?>" border="0" class="picture" title="<?php echo $i['image']['image_title'];?>" alt="" /></a><br />
								</td>
								<td valign="top" class="txt_footer">
									<a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><?php echo $i['user_firstname'];?> <?php echo $i['user_surname'];?></a>&nbsp;(<?php echo $i['user_nic'];?>)<br />

									<?php echo $i['user_create_datetime'];?><br />
									<?php echo $i['user_hometown'];?><br />

									<?php
									if ($i['online_status'] == 1) {
									    echo "<span class='txt_red'><b>" . $lang['arr_user_online_status'][1] . "</b></span><br />";
									}
									else {
										    echo $lang['arr_user_online_status'][$i['online_status']] . "<br />";
									}
									?>
								</td>
								<td width="10" valign="top">
									<a href="msg_compose.php?to_user_id=<?php echo $i['user_id'];?>"><img src="<?php echo $templatePath;?>img/unopenned_mail.png" title="<?php echo $lang['ttl_send_message'];?>" border="0" alt="" /></a><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td colspan="3">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td colspan="3">
						<?php echo $lang['err_no_friends'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_menu'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<a href="sn_invite.php" class="txt_sub_menu"><?php echo $lang['href_invite'];?></a><br />
						<a href="my_profile.php" class="txt_sub_menu"><?php echo $lang['href_profile'];?></a><br />
						<a href="<?php echo $lang['arr_link'][1];?>" class="txt_sub_menu"><?php echo $lang['href_help'];?></a><br />
						<?php if (!isset($homepage)) { ?>
							<a href="<?php echo $page_name;?>?homepage=1" class="txt_sub_menu" title="<?php echo $lang['ttl_homepage_set'];?>"><?php echo $lang['href_homepage_set'];?></a><br />
						<?php  } ?>
			
			
					
					</td>
				</tr>
			</table>

		</td>

		<td width="20">&nbsp;</td>

		<td width="375" valign="top">
		<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_discussions'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($discussions_recommended[0])) {
				foreach($discussions_recommended as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="g_forum_subject.php?group_id=<?php echo $i['group_id'];?>&amp;topic_id=<?php echo $i['topic_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></a><br />
						<span class="txt_footer"><?php echo dots(200,$i['subject_body']);?></span><br />
					</td>
			    </tr>
				<?if (isset($i['poll'])) {?>
				<tr>
					<td align="right">
						<?php
						include $templatePath . "poll.inc.tpl.php";
						?>
					</td>
				</tr>
				<?php
				}
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_subjects'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="3" class="txt_title" align="right">
						<?php echo $lang['hdr_blogs'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($blogs[0])) {
				foreach($blogs as $key => $i):
				?>
				<tr>
					<td width="1%">
						<a href="sn_blog.php?user_id=<?php echo $i['user_id'];?>&amp;blog_id=<?php echo $i['blog_id'];?>"><img align="left" src="get_image.php?img=<?php echo $i['image']['image'];?>" border="0" class="picture" title="<?php echo $i['image']['image_title'];?>" alt="" /></a>
					</td>
					<td valign="top">
						<a href="sn_blog.php?user_id=<?php echo $i['user_id'];?>&amp;blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_title'];?></a><br />
						<span class="txt_footer"><?php echo $i['blog_create_datetime'];?></span><br />
						<span class="txt_footer"><?php echo $i['blog_synopsis'];?></span><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_latest_groups'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($latest_groups[0])) {
				foreach($latest_groups as $key => $i):
				?>

			    <tr>
					<td width="60%">
						<?php
						if (isset($i['image']['image_id'])) {
						?>
							<img align="left" src="get_image.php?img=<?php echo $i['image']['image'];?>" border="0" class="picture" title="<?php echo $i['image']['image_title'];?>" alt="" / />
						<?
						}
						?>
						<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a><br />
						<?php echo $i['group_synopsis'];?><br />
						<p class="txt_footer">
						<?php echo $lang['txt_recommended_age'];?>:
						<?
						if ($i['group_from_age'] && $i['group_to_age']) {
						    echo $i['group_from_age'] . "/" . $i['group_to_age'];
						}
						else if ($i['group_from_age'] && !$i['group_to_age']) {
							echo $lang['txt_age_from'] . " " . $i['group_from_age'];
						}
						else if (!$i['group_from_age'] && $i['group_to_age']) {
							echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
						}
						else {
							echo $lang['txt_age_all'];
						}
						?>,
						<?php echo $lang['txt_genre'];?>: <?if (isset($i['genre_id'])) { echo $lang['arr_genre'][$i['genre_id']];}?>
						,
						<?php echo $lang['txt_group_type'];?>: <?if (isset($i['group_type'])) { echo $lang['arr_group_type'][$i['group_type']];}?><br />

					</td>
			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_groups'];?>
						<br />
					</td>
				</tr>
				<?php }?>
			</table>
		</td>
	</tr>
</table>

==> aroundme-0_4_0.tar: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/welcome.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>

<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="375" valign="top">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_welcome'] . " " . $user['user_firstname'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_introduction'];?><br />
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" width="100%" cellspacing="4" cellpadding="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_membership'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_membership_introduction'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<tr>
					<td>
						<a href="my_membership.php"><?php echo $lang['href_membership'];?></a><br />
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" width="100%" cellspacing="4" cellpadding="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_profile'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_profile_introduction'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<tr>
					<td>
						<a href="my_profile.php"><?php echo $lang['href_profile'];?></a><br />
					</td>
				</tr>
			</table>
		</td>

		<td width="20">&nbsp;</td>

		<td width="375" valign="top">
			<table border="0" width="100%" cellspacing="4" cellpadding="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_friends'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_friends_introduction'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<tr>
					<td>
						<a href="sn_network.php"><?php echo $lang['href_friends'];?></a><br />
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" width="100%" cellspacing="4" cellpadding="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_help'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_help_introduction'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<tr>
					<td>
						<a href="<?php echo $lang['arr_link'][1];?>"><?php echo $lang['href_help1'];?></a><br />
					</td>
				</tr>
			</table>
		</td>
	</tr>
</table>
